@@ -4,7 +4,7 @@ use vars qw($VERSION);
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.79_06';
+$VERSION = '0.79_07';
 
 sub _include_no_monolith {
    # no monolith eh?
@@ -84,6 +84,10 @@ sub _include {
    }
    else {
       $interpolate = 1; # just guessing ...
+      return "qq~$err Interpolated includes don't work under monolith option. "
+            ."Please disable monolith and use the 'SHARE' directive in the"
+            ." include command: $file~"
+         if $self->[MONOLITH];
    }
 
    return "q~$err '" . escape('~' => $file) . "' is a directory~"
@@ -197,8 +201,8 @@ Private module.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.79_06> of C<Text::Template::Simple::Base::Include>
-released on C<5 August 2009>.
+This document describes version C<0.79_07> of C<Text::Template::Simple::Base::Include>
+released on C<6 August 2009>.
 
 B<WARNING>: This version of the module is part of a
 developer (beta) release of the distribution and it is
